@@ -105,7 +105,6 @@ as_chunk <- function(x, props = NULL, formater = format_fun, ...) {
   data
 }
 
-#' @importFrom magick image_read
 #' @importFrom grDevices as.raster
 #' @export
 #' @title image chunk wrapper
@@ -143,9 +142,9 @@ as_image <- function(src, width = .5, height = .2, ...) {
 
   data <- chunk_dataframe(width = as.double(width),
                   height = as.double(height),
-                  img_data = lapply(src, function(x) as.raster(image_read(x)))
+                  img_data = src
                   )
-  class(data) <- c("img_chunk", "chunk", "data.frame")
+  class(data) <- c("img_src", "chunk", "data.frame")
   data
 }
 
@@ -173,7 +172,7 @@ as_image <- function(src, width = .5, height = .2, ...) {
 #' @family chunk elements for paragraph
 hyperlink_text <- function(x, props = NULL, formater = format_fun, url, ...){
   x <- as_chunk( x = x, props = props, formater = formater, ...)
-  x$url <- rep(url, nrow(x))
+  x$url <- url
   x
 }
 
@@ -237,6 +236,86 @@ minibar <- function(value, max = NULL, barcol = "#CCCCCC", bg = "transparent", w
   z
 }
 
+#' @export
+#' @title mini linerange chunk wrapper
+#' @description This function is used to insert lineranges into
+#' flextable with function \code{\link{compose}}.
+#' It should be used inside a call to \code{\link{as_paragraph}}
+#' @param value values containing the bar size
+#' @param min min bar size. Default min of value
+#' @param max max bar size. Default max of value
+#' @param rangecol bar color
+#' @param stickcol jauge color
+#' @param bg background color
+#' @param width,height size of the resulting png file in inches
+#' @param raster_width number of pixels used as width
+#' when interpolating value.
+#' @note PowerPoint cannot mix images and text in a paragraph, images
+#' are removed when outputing to PowerPoint format.
+#' @family chunk elements for paragraph
+#' @examples
+#' myft <- flextable( head(iris, n = 10 ))
+#'
+#' myft <- compose( myft, j = 1,
+#'   value = as_paragraph(
+#'     linerange(value = Sepal.Length)
+#'   ),
+#'   part = "body")
+#'
+#' autofit(myft)
+#' @importFrom grDevices as.raster col2rgb rgb
+#' @importFrom stats approx
+#' @seealso \code{\link{compose}}, \code{\link{as_paragraph}}
+linerange <- function(value, min = NULL, max = NULL, rangecol = "#CCCCCC",
+                      stickcol = "#FF0000", bg = "transparent", width = 1,
+                      height = .2, raster_width = 30) {
+  if( all( is.na(value) ) ){
+    min <- 0
+    max <- 1
+  }
+
+  if( raster_width < 2)
+    stop("raster_width must be greater than 1")
+
+  raster_nrow <- 9
+  raster_center <- 5
+
+  if( is.null(max))
+    max <- max(value, na.rm = TRUE)
+  if ( is.null(min))
+    min <- min(value, na.rm = TRUE)
+
+  value[!is.finite(value)] <- max + 1 # to be sure not displayed
+
+  stopifnot(!is.null(value), !is.null(min), !is.null(min))
+
+  # transform color code
+  stickcol  <- rgb(t(col2rgb(stickcol))/255)
+  rangecol  <- rgb(t(col2rgb(rangecol))/255)
+  bg <- ifelse( bg == "transparent", bg, rgb(t(col2rgb(bg))/255) )
+
+
+  # get value approx on range 1,raster_width
+  stick_pos <- as.integer(approx(x = c(min,max), y = c(1, raster_width), xout = value)$y)
+  base <- matrix(bg, nrow = raster_nrow, ncol = raster_width)
+  base[, 1]   <- rangecol
+  base[, raster_width] <- rangecol
+  base[raster_center,] <- rangecol
+
+  rasters <- lapply(stick_pos, function(val, def_mat, col) {
+    newmat <- def_mat
+    newmat[, val] <- col
+    as.raster(newmat)
+  }, base, stickcol)
+
+  z <- chunk_dataframe(width = as.double(rep(width, length(value)) ),
+                  height = as.double(rep(height, length(value))),
+                  img_data = rasters )
+
+  class(z) <- c("img_chunk", "chunk", "data.frame")
+  z
+
+}
 
 #' @export
 #' @title concatenate chunks in a flextable
